Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(195)

Unified Diff: chrome/browser/ui/views/payments/editor_view_controller.cc

Issue 2859193004: Remove GridLayout::SetInsets in favor of an empty border on the host. (Closed)
Patch Set: fix compile and tests Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/payments/editor_view_controller.cc
diff --git a/chrome/browser/ui/views/payments/editor_view_controller.cc b/chrome/browser/ui/views/payments/editor_view_controller.cc
index a33a40fe82ad3ffb98891f462dd651f8f1f419eb..1e4d02e5e9f50d4ca92918c85bb26914f4b3ef71 100644
--- a/chrome/browser/ui/views/payments/editor_view_controller.cc
+++ b/chrome/browser/ui/views/payments/editor_view_controller.cc
@@ -156,13 +156,13 @@ std::unique_ptr<views::View> EditorViewController::CreateEditorView() {
std::unique_ptr<views::GridLayout> editor_layout =
base::MakeUnique<views::GridLayout>(editor_view.get());
// The editor grid layout is padded vertically from the top and bottom, and
// horizontally inset like other content views. The top padding needs to be
// added to the top padding of the first row.
constexpr int kEditorVerticalInset = 16;
- editor_layout->SetInsets(
+ editor_view->SetBorder(views::CreateEmptyBorder(
kEditorVerticalInset, payments::kPaymentRequestRowHorizontalInsets,
- kEditorVerticalInset, payments::kPaymentRequestRowHorizontalInsets);
+ kEditorVerticalInset, payments::kPaymentRequestRowHorizontalInsets));
views::ColumnSet* columns = editor_layout->AddColumnSet(0);
columns->AddColumn(views::GridLayout::LEADING, views::GridLayout::CENTER, 0,
@@ -156,13 +156,13 @@ std::unique_ptr<views::View> EditorViewController::CreateEditorView() {
std::unique_ptr<views::GridLayout> editor_layout =
base::MakeUnique<views::GridLayout>(editor_view.get());
- // The editor grid layout is padded vertically from the top and bottom, and
- // horizontally inset like other content views. The top padding needs to be
+ // The editor view is padded vertically from the top and bottom, and
+ // horizontally padded like other content views. The top padding needs to be
// added to the top padding of the first row.
constexpr int kEditorVerticalInset = 16;

Powered by Google App Engine
This is Rietveld 408576698